
* DKdis02.do - Exercises, Set 7
* Cluster analysis of change in aggregate party choice
* Adapted from DKdis01.do

set more off

use "m:\stata\DKdistricts.dta", clear

* Preparing data
*****************

* Inspect DP98
*sum dpoe98-votdp98

* Compute percent of all votes for all parties
foreach v of varlist dpoe98 dpf98 dpu98 dpa98 dpb98 dpd98 dpq98 dpc98 /*
  */ dpv98 dpo98 dpz98 xdp98 spldp98 absdp98 {
gen p`v' = `v'/votdp98*100 
  }

* Weighted percentages
sum pdpoe98-pabsdp98 [aw=votdp98]

* Compute logit shares for all parties
foreach v of varlist dpoe98 dpf98 dpu98 dpa98 dpb98 dpd98 dpq98 dpc98 /*
  */ dpv98 dpo98 dpz98 xdp98 spldp98 absdp98 {
gen l`v' = ln(p`v'/(100-p`v')) 
  }
sum ldpoe98-labsdp98 [aw=votdp98]

* Compute percentages and logits for DP 2001
********************************************

* Inspect DP01
*sum dpoe01-votdp01

* Compute percentages for all parties
foreach v of varlist dpoe01 dpf01 dpa01 dpb01 dpd01 dpq01 dpc01 /*
  */ dpv01 dpo01 dpz01 xdp01 spldp01 absdp01 {
gen p`v' = `v'/votdp01*100 
  }
sum pdpoe01-pabsdp01 [aw=votdp01]

* Compute logits for all parties
foreach v of varlist dpoe01 dpf01 dpa01 dpb01 dpd01 dpq01 dpc01 /*
  */ dpv01 dpo01 dpz01 xdp01 spldp01 absdp01 {
gen l`v' = ln(p`v'/(100-p`v')) 
  }
sum ldpoe01-labsdp01 [aw=votdp01]

* Factor analysis
*****************

*obliraw ldpoe98-ldpz98 labsdp98 ldpoe01-ldpz01 labsdp01 [aw=votdp01], factors(2)

*greigen

* Study of party swing

* Socialist People's Party (SPP) from 1998 to 2001

* Regression Analysis
*********************
pause on

*Scatter diagram
scatter ldpf01 ldpf98, xtitle(SPP 1998: logit scale) ytitle(SPP 2001: logit scale)
pause

*Enter q to continue

* Simple regression analysis weighted by unit size
regress ldpf01 ldpf98 [aweight=votdp01 ]

* Get coefficients
matrix coefs = e(b)
gen a = coefs[1,2]
gen b = coefs[1,1]
gen tendency = a + b*ldpf98

* Draw scatter diagram
scatter ldpf01 ldpf98, xtitle(SPP 1998: logit scale) ytitle(SPP 2001: logit scale) /*
*/ || line tendency ldpf98
pause
drop a b tendency


* Preparing errors-in-variables regression

* find correlation
correlate ldpf98 ldpf01 [aweight=votdp01 ]

* Error-in-variables regression analysis weighted by unit size
eivreg ldpf01 ldpf98 [aweight=votdp01], reliab(ldpf98 `r(rho)')

* Get coefficients
matrix coefs = e(b)
gen a = coefs[1,2]
gen b = coefs[1,1]
gen tendency = a + b*ldpf98

* Draw scatter diagram
scatter ldpf01 ldpf98, xtitle(SPP 1998: logit scale) ytitle(SPP 2001: logit scale) /*
*/ || line tendency ldpf98
pause

* Draw symmetric scattergram
twoway (scatter ldpf01 ldpf98, sort) (line tendency ldpf98, sort clpat(solid)),/*
*/ ytitle(SPP 2001: logit scale, margin(medsmall)) yscale(range(-4 -1.5))/*
*/ xtitle(SPP 1998: logit scale, margin(medsmall)) xscale(range(-4 -1.5))/*
*/ xlabel(-4(0.5) -1.5, grid) legend(off) ysize(4) xsize(5)/* 
*/graphregion(fcolor(white) lcolor(black))
pause

gen region2 = region

* Draw symmetric scattergram with region code
twoway (scatter ldpf01 ldpf98, sort msymbol(none) mlabel(region2)/* 
*/ mlabposition(0))(line tendency ldpf98, sort clpat(solid)),/*
*/ ytitle(SPP 2001: logit scale, margin(medsmall)) yscale(range(-4 -1.5))/*
*/ xtitle(SPP 1998: logit scale, margin(medsmall)) xscale(range(-4 -1.5))/*
*/ xlabel(-4(0.5)-1.5, grid) legend(off) ysize(4) xsize(5)/* 
*/graphregion(fcolor(white) lcolor(black))
pause

drop a b tendency region2

* Repeat the same for CD
* Simple regression analysis weighted by unit size
regress ldpd01 ldpd98 [aweight=votdp01 ]

* Get coefficients
matrix coefs = e(b)
gen a = coefs[1,2]
gen b = coefs[1,1]
gen tendency = a + b*ldpd98

* Draw scatter diagram
scatter ldpd01 ldpd98, xtitle(CD 1998: logit scale) ytitle(CD 2001: logit scale) /*
*/ || line tendency ldpd98
pause
drop a b tendency

* Preparing error-in-variables regression

* find correlation
correlate ldpd98 ldpd01 [aweight=votdp01 ]

* Error-in-variables regression analysis weighted by unit size
eivreg ldpd01 ldpd98 [aweight=votdp01], reliab(ldpd98 `r(rho)')

* Get coefficients
matrix coefs = e(b)
gen a = coefs[1,2]
gen b = coefs[1,1]
gen tendency = a + b*ldpd98

* Draw scatter diagram
scatter ldpd01 ldpd98, xtitle(CD 1998: logit scale) ytitle(CD 2001: logit scale) /*
*/ || line tendency ldpd98
pause

* Draw symmetric scattergram
twoway (scatter ldpd01 ldpd98, sort) (line tendency ldpd98, sort clpat(solid)),/*
*/ ytitle(CD 2001: logit scale, margin(medsmall)) yscale(range(-5 -2.5))/*
*/ xtitle(CD 1998: logit scale, margin(medsmall)) xscale(range(-5 -2.5))/*
*/ xlabel(-5(0.5) -2.5, grid) legend(off) ysize(4) xsize(5)/* 
*/graphregion(fcolor(white) lcolor(black))
pause

gen region2 = region

* Draw symmetric scattergram with region code
twoway (scatter ldpd01 ldpd98, sort msymbol(none) mlabel(region2)/* 
*/ mlabposition(0))(line tendency ldpd98, sort clpat(solid)),/*
*/ ytitle(CD 2001: logit scale, margin(medsmall)) yscale(range(-5 -2.5))/*
*/ xtitle(CD 1998: logit scale, margin(medsmall)) xscale(range(-5 -2.5))/*
*/ xlabel(-5(0.5)-2.5, grid) legend(off) ysize(4) xsize(5)/* 
*/graphregion(fcolor(white) lcolor(black))
pause

drop a b tendency region2

*Cluster analysis
*****************

* Logit change for all parties (except u, x and spl)
egen ddpoe01 = std(ldpoe01 - ldpoe98)
egen ddpf01 = std(ldpf01 - ldpf98)
egen ddpa01 = std(ldpa01 - ldpa98)
egen ddpd01 = std(ldpd01 - ldpd98)
egen ddpq01 = std(ldpq01 - ldpq98)
egen ddpc01 = std(ldpc01 - ldpc98)
egen ddpv01 = std(ldpv01 - ldpv98)
egen ddpo01 = std(ldpo01 - ldpo98)
egen ddpz01 = std(ldpz01 - ldpz98)
egen ddpabs01 = std(labsdp01 - labsdp98)
sum ddpoe01-ddpabs01

cluster wardslinkage dd*
cluster generate ward = groups(2/12)

*saveold "m:\Stata\clusters.dta"
saveold "m:\Stata\clusters.dta", replace

